@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-diff-ansi
-;; Package-Version: 20251216.227
-;; Package-Revision: dd600ebdc632
+;; Package-Version: 20260108.1512
+;; Package-Revision: 98f1837840e9
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -98,13 +98,13 @@ This must take the diff content as the `standard-input'."
 (defcustom diff-ansi-chunks-size 16384
   "Number of characters to process at once.
 Used for `progressive' and `multiprocess' methods."
-  :type 'integer)
+  :type 'natnum)
 
 (defcustom diff-ansi-multiprocess-jobs nil
   "Number of simultaneous jobs to launch when using `multiprocess' method.
 
-A nil value detects the number of processes on the system (when supported)."
-  :type '(choice (const :tag "Auto-detect" nil) integer))
+A nil value auto-detects the number of processors using `num-processors'."
+  :type '(choice (const :tag "Auto-detect" nil) (natnum :tag "Number of jobs")))
 
 (defcustom diff-ansi-verbose-progress nil
   "When enabled, show the progress of progressive conversion in the echo area.
@@ -156,7 +156,7 @@ It can be useful to show progress when viewing very large diffs."
 ;; Forward Declarations
 
 ;; Needed since the `eval' causes the function to be hidden.
-(declare-function diff-ansi--ansi-color-apply-on-region-with-bg-impl "diff-ansi")
+(declare-function diff-ansi--ansi-color-apply-on-region-with-bg-impl "ansi-color")
 (declare-function magit-wash-sequence "magit-section")
 
 
@@ -166,7 +166,7 @@ It can be useful to show progress when viewing very large diffs."
 (defmacro diff-ansi--with-advice (advice &rest body)
   "Execute BODY with ADVICE temporarily enabled.
 
-Advice are triplets of (SYMBOL HOW FUNCTION),
+Each advice is a triplet of (SYMBOL HOW FUNCTION),
 see `advice-add' documentation."
   (declare (indent 1))
   (let ((advice-list advice)
@@ -764,13 +764,12 @@ Store the result in TARGET-BUF when non-nil."
         (diff-ansi--call-process-pipe-chain diff-command :input diff-str :output (current-buffer))
         (setq end (point))
 
-        ;; Postpone activation until the timer can take itself as an argument.
-        (diff-ansi--with-advice ((#'timer-activate :override (lambda (&rest _) nil)))
-          (setq diff-ansi--ansi-color-timer (run-at-time 0.0 0.001 nil))
-          (timer-set-function diff-ansi--ansi-color-timer #'diff-ansi-progressive-highlight-impl
-                              (list
-                               (current-buffer) beg (cons beg end) diff-ansi--ansi-color-timer)))
-        (timer-activate diff-ansi--ansi-color-timer)))))
+        (letrec ((timer
+                  (run-at-time 0.0 0.001
+                               (lambda (buf beg range)
+                                 (diff-ansi-progressive-highlight-impl buf beg range timer))
+                               (current-buffer) beg (cons beg end))))
+          (setq diff-ansi--ansi-color-timer timer))))))
 
 
 ;; ---------------------------------------------------------------------------
@@ -958,7 +957,7 @@ Return the buffer used to write data into on success."
 
     (let ((method diff-ansi-method))
 
-      ;; Fallback to immediate when the task wont be split.
+      ;; Fallback to immediate when the task won't be split.
       (when (<= (- end beg) diff-ansi-chunks-size)
         (setq method 'immediate))
 
